Commit in lcsim/src/org/lcsim/fit/helicaltrack on MAIN
HelicalTrackFitter.java+7-31.32 -> 1.33
Fix bug where the code didn't check the barrel/endcap status of a pixel hit before creating a pseudo axial strip hit for use in a a zsegment fit with exactly one pixel hit

lcsim/src/org/lcsim/fit/helicaltrack
HelicalTrackFitter.java 1.32 -> 1.33
diff -u -r1.32 -r1.33
--- HelicalTrackFitter.java	1 Feb 2011 22:54:24 -0000	1.32
+++ HelicalTrackFitter.java	3 Feb 2011 18:44:28 -0000	1.33
@@ -4,7 +4,7 @@
  *
  * Created on March 25, 2006, 6:11 PM
  *
- * $Id: HelicalTrackFitter.java,v 1.32 2011/02/01 22:54:24 partridge Exp $
+ * $Id: HelicalTrackFitter.java,v 1.33 2011/02/03 18:44:28 partridge Exp $
  */
 
 import hep.physics.matrix.SymmetricMatrix;
@@ -314,12 +314,16 @@
 
             //  Not enough pixel hits for a line fit, do a ZSegment fit
 
             //  If we have one pixel hit, turn it into a pseudo strip hit
             if (npix == 1) {
                 //  Get the pixel hit (there should only be 1)
                 HelicalTrackHit hit = pixel_hits.get(0);
+                //  Only do this for barrel hits
+                if (hit.BarrelEndcapFlag() == BarrelEndcapFlag.BARREL) {
                 //  Create a pseudo strip hit and add it to the list of strip hits
-                strip_hits.add(HitUtils.PixelToStrip(hit, smap, msmap, oldhelix, _tolerance));
+                    strip_hits.add(
+                            HitUtils.PixelToStrip(hit, smap, msmap, oldhelix, _tolerance));
+                }
             }
 
             //  We should always have enough hits for a ZSegment fit
@@ -314,12 +314,16 @@
             //  Not enough pixel hits for a line fit, do a ZSegment fit
 
-            //  If we have one pixel hit, turn it into a pseudo strip hit
+            //  If we have one barrel pixel hit, turn it into a pseudo strip hit
             if (npix == 1) {
                 //  Get the pixel hit (there should only be 1)
CVSspam 0.2.8